#!/bin/sh



#################################################################
#                                                               #
#               Update u-boot.bin                               #
#                                                               #
#################################################################
update_uboot() {
	info "=== OVERLOADED FUNCTION Updating U-BOOT..."
        info "Updating U-BOOT..."
        # PR 1741
        # cat /dev/zero > ${UBOOT_MTD_PART}
        flash_eraseall ${UBOOT_MTD_PART} > /dev/null 2>&1
        nandwrite -p ${UBOOT_MTD_PART} ${1} > /dev/null 2>&1
        RET=$?
        if [ $RET -eq 0 ]; then
                mv ${1} ${1}.OK
                info "U-BOOT Updated"
        fi
        return $RET
}

#################################################################
#                                                               #
#                    Rootfs operations                          #
#                                                               #
#################################################################
update_rootfs() {
        sleep 1
	info "=== OVERLOADED FUNCTION Format RootFS partition..."
        info "Format RootFS partition..."
        flash_eraseall ${ROOTFS_MTD_PART} > /dev/null 2>&1 || return 1
        mount -t yaffs2 ${ROOTFS_PART} ${MOUNT_POINT_ROOTFS} > /dev/null 2>&1 || return 1
        cd ${MOUNT_POINT_ROOTFS}
        info "Programming rootfs..."
        tar xpf $1
        ret=$?
        # PR 2797: link correct knetd.xml
        if ! [ -f ${MOUNT_POINT_ROOTFS}/knet/knetd.xml ]
                then
                cp -L ${MOUNT_POINT_ROOTFS}/knet/.configs/knetd_`get_product`.xml ${MOUNT_POINT_ROOTFS}/knet/knetd.xml
        fi
        cd - > /dev/null 2>&1
        sync
        umount -f ${MOUNT_POINT_ROOTFS} > /dev/null 2>&1 || error "umount ${ROOTFS_PART}."
        info "Rootfs updated"
}


prod_flash_rootfs() {
        PROD_IMAGE=${1}

        update_rootfs ${PROD_IMAGE}
	info "=== OVERLOADED FUNCTION Flashing rescuefs"
        info "Flashing rescuefs"
        # PR 1741
        # cat /dev/zero > ${RESCUEFS_MTD_PART}
        flash_eraseall ${RESCUEFS_MTD_PART} > /dev/null 2>&1
        mount -t yaffs2 ${RESCUEFS_PART} ${MOUNT_POINT_RESCUEFS}
        cp ${PROD_IMAGE} ${MOUNT_POINT_RESCUEFS}/${FS_RESCUE}
        [ $? -ne 0 ] && return 1

# Gzip includes CRC verification so MD5 is useless
#       cd ${MOUNT_POINT_RESCUEFS}
#       md5sum ${FS_RESCUE} > ${FS_RESCUE}.md5
#       cd /
        sync
        umount ${MOUNT_POINT_RESCUEFS}
        usleep 100
        info "rescuefs programmed"
        rm -f ${PROD_IMAGE}
        return 0
}


#################################################################
#                                                               #
#                    Userfs operations                          #
#                                                               #
#################################################################
update_userfs() {
#       sleep 1
        info "=== OVERLOADED FUNCTION Erasing Userfs ...."
	info "Erasing Userfs"
        # PR 1741
        #cat /dev/zero > ${USERFS_MTD_PART}
        flash_eraseall ${USERFS_MTD_PART} > /dev/null 2>&1
        info "Mount UserFS partition to be updated."
        mount -t yaffs2 ${USERFS_PART} ${MOUNT_POINT_TOBEUPDATED} > /dev/null 2>&1
        cd ${MOUNT_POINT_TOBEUPDATED} > /dev/null 2>&1 || error "'cd' problem."
        info "Programming Userfs..."
        tar xpf $1
        cd - > /dev/null 2>&1 || error "'cd' problem."
        sync
        umount -f ${MOUNT_POINT_TOBEUPDATED} > /dev/null 2>&1 || error "umount ${USERFS_PART}."
        info "New UserFS updated."
}

generate_rescuefs()
{

        info "=== OVERLOADED FUNCTION Dumping rootfs ...." 
	info "Dumping rootfs ...."
        dump_rootfs ${TMP_DIR}/${ROOTFS_IMAGE}
        [ $? -ne 0 ] && return 1

   info "Check Size"
   image_size=`ls -l ${TMP_DIR}/${ROOTFS_IMAGE} | awk '{print $5}'`
        # Take bad blocks into account
        if [ ${image_size} -ge $((${RESCUEFS_PART_SIZE}-5*${NAND_BLK_SIZE})) ]
        then
                error "Generated rootfs is too big to be saved (${image_size} B), abort !"
                return 2
        fi

        info "Format RescueFS partition"
        # PR 1741
        # cat /dev/zero > ${RESCUEFS_MTD_PART}
        flash_eraseall ${RESCUEFS_MTD_PART} > /dev/null 2>&1 || return 1
        info "Mount RescueFS partition to be updated."
        mount -t yaffs2 ${RESCUEFS_PART} ${MOUNT_POINT_RESCUEFS} > /dev/null 2>&1 || return 1

        mv ${TMP_DIR}/${ROOTFS_IMAGE} ${MOUNT_POINT_RESCUEFS}/${FS_RESCUE}
        ret=$?

        sync
        umount ${MOUNT_POINT_RESCUEFS}
        return $ret
}



echo " == disable watchdog during this long upgrade"
wirma2hw wd down


